/**
 * @file Utilities - extRegex
 * @module ext-regex/utils/extRegex
 */
import type { Options } from '../interfaces/index.mjs';
import * as pathe from '@flex-development/pathe';
import { type LiteralUnion } from '@flex-development/tutils';
/**
 * Creates a regular expression matching the given file extension, `ext`.
 *
 * The file extension does not need to begin with a dot character (`'.'`). If it
 * doesn't, however, it will be formatted before being converted into a regular
 * expression pattern. The returned regular expression will match the formatted
 * file extension instead.
 *
 * Throws `ERR_INVALID_ARG_TYPE` if the given file extension is not a string.
 *
 * @see {@linkcode pathe.Ext}
 * @see {@linkcode errnode.ERR_INVALID_ARG_TYPE}
 *
 * @param {LiteralUnion<pathe.Ext, string>} ext - File extension to evaluate
 * @param {Options?} [options] - Regular expression options
 * @return {RegExp} Regular expression matching `ext`
 * @throws {errnode.NodeError<TypeError>} If `ext` is not a string
 */
declare const extRegex: (ext: LiteralUnion<pathe.Ext, string>, options?: Options) => RegExp;
export default extRegex;
